@@ -1,15 +1,10 @@
 use strict;
 use warnings;
 
-package Test::CleanNamespaces;
-BEGIN {
-  $Test::CleanNamespaces::AUTHORITY = 'cpan:FLORA';
-}
-# git description: v0.14-1-ge35dfaa
-$Test::CleanNamespaces::VERSION = '0.15';
+package Test::CleanNamespaces; # git description: v0.16-4-g2259488
 # ABSTRACT: Check for uncleaned imports
 # KEYWORDS: testing namespaces clean dirty imports exports subroutines methods
-
+$Test::CleanNamespaces::VERSION = '0.17';
 use Module::Runtime qw(require_module module_notional_filename);
 use Sub::Identify qw(sub_fullname stash_name);
 use Package::Stash 0.14;
@@ -138,7 +133,7 @@ sub _remaining_imports {
         @imports = keys %subs;
     }
     elsif ($INC{ module_notional_filename('Mouse::Util') }
-        and $meta = Mouse::Util::class_of($ns))
+        and Mouse::Util->can('class_of') and $meta = Mouse::Util::class_of($ns))
     {
         warn 'Mouse class detected - chance of false negatives is high!';
 
@@ -164,7 +159,7 @@ sub _remaining_imports {
     # is important
     delete @imports{qw(import unimport)};
 
-    my @overloads = grep { $imports{$_} eq 'overload::nil' } keys %imports;
+    my @overloads = grep { $imports{$_} eq 'overload::nil' || $imports{$_} eq 'overload::_nil' } keys %imports;
     delete @imports{@overloads} if @overloads;
 
     if ($] < 5.010)
@@ -224,7 +219,7 @@ Test::CleanNamespaces - Check for uncleaned imports
 
 =head1 VERSION
 
-version 0.15
+version 0.17
 
 =head1 SYNOPSIS
 
